@@ -15,6 +15,8 @@ from contextlib import contextmanager
 from random import Random
 from threading import RLock
 
+import pytest
+
 from hypothesis import HealthCheck, Phase, settings, strategies as st
 from hypothesis.control import current_build_context, currently_in_test_context
 from hypothesis.internal.conjecture import engine as engine_module
@@ -27,7 +29,6 @@ from hypothesis.internal.conjecture.provider_conformance import (
 )
 from hypothesis.internal.conjecture.providers import COLLECTION_DEFAULT_MAX_SIZE
 from hypothesis.internal.conjecture.utils import calc_label_from_name
-from hypothesis.internal.entropy import deterministic_PRNG
 from hypothesis.internal.escalation import InterestingOrigin
 from hypothesis.internal.floats import SMALLEST_SUBNORMAL
 from hypothesis.internal.intervalsets import IntervalSet
@@ -52,17 +53,17 @@ def interesting_origin(n: int | None = None) -> InterestingOrigin:
 
 
 def run_to_data(f):
-    with deterministic_PRNG():
-        runner = ConjectureRunner(
-            f,
-            settings=settings(
-                max_examples=300, database=None, suppress_health_check=list(HealthCheck)
-            ),
-        )
-        runner.run()
-        assert runner.interesting_examples
-        (last_data,) = runner.interesting_examples.values()
-        return last_data
+    runner = ConjectureRunner(
+        f,
+        settings=settings(
+            max_examples=300, database=None, suppress_health_check=list(HealthCheck)
+        ),
+        random=Random(0),
+    )
+    runner.run()
+    assert runner.interesting_examples
+    (last_data,) = runner.interesting_examples.values()
+    return last_data
 
 
 def run_to_nodes(f):
@@ -85,32 +86,28 @@ def buffer_size_limit(n):
 
 def shrinking_from(start):
     def accept(f):
-        with deterministic_PRNG():
-            runner = ConjectureRunner(
-                f,
-                settings=settings(
-                    max_examples=5000,
-                    database=None,
-                    suppress_health_check=list(HealthCheck),
-                    # avoid running the explain phase in shrinker.shrink() in tests
-                    # which don't test the inquisitor.
-                    phases=set(settings.default.phases) - {Phase.explain},
-                ),
-            )
-            runner.cached_test_function(start)
-            assert runner.interesting_examples
-            (last_data,) = runner.interesting_examples.values()
-            return runner.new_shrinker(
-                last_data, lambda d: d.status == Status.INTERESTING
-            )
+        runner = ConjectureRunner(
+            f,
+            settings=settings(
+                max_examples=5000,
+                database=None,
+                suppress_health_check=list(HealthCheck),
+                # avoid running the explain phase in shrinker.shrink() in tests
+                # which don't test the inquisitor.
+                phases=set(settings.default.phases) - {Phase.explain},
+            ),
+            random=Random(0),
+        )
+        runner.cached_test_function(start)
+        assert runner.interesting_examples
+
+        (last_data,) = runner.interesting_examples.values()
+        return runner.new_shrinker(last_data, lambda d: d.status == Status.INTERESTING)
 
     return accept
 
 
 def fresh_data(*, random=None, observer=None) -> ConjectureData:
-    # support importing this file from our nose job, which doesn't have pytest
-    import pytest
-
     context = current_build_context() if currently_in_test_context() else None
     if context is not None and settings().backend == "crosshair":
         # we should reeaxmine fresh_data sometime and see if we can replace it
